@@ -10,55 +10,67 @@ cmp (gconstpointer a, gconstpointer b)
   return (two.lon)-(one.lon);
 }
 
-void enum_timezones(GtkWidget *clist )
+void enum_timezones(asclock *my_asclock, GtkWidget *clist )
 {
   FILE *tz;
   GSList * my;
-  char line[1024], *pos, *localtime = NULL;
-  char *newelem[3] = { line, NULL, NULL };
+  char line[1024], *pos;
+  char *newelem[3] = { NULL, NULL, NULL };
   gpointer localtime_data = NULL;
   int inspos, len, row;
 
+  newelem[0] = line;
+
   tz = fopen("/usr/share/zoneinfo/zone.tab", "r");
+  if(!tz) {
+    fprintf(stderr, "/usr/share/zoneinfo/zone.tab not found...\n");
+    return;
+  }
 
-  len = readlink ("/etc/localtime", line, sizeof (line)-1);
-  if (len < 0) goto cannot_read_localtime;
-  line [len] = 0;
+  /* if we do not have a timezone set, use the one from /etc/localtime */
+  if(strlen(my_asclock->timezone)==0) 
+  {
+    len = readlink("/etc/localtime", line, sizeof(line)-1);
+    if(len>=0)
+      {
+        line [len] = 0;
+ 
+        pos = strstr (line, "zoneinfo/");
+        if (pos)
+	  {
+	    pos += strlen ("zoneinfo/");
+	    strncpy(my_asclock->timezone, g_strdup (pos), MAX_PATH_LEN);
+ 	  }
+      }
+  }
+  strcpy(my_asclock->selected_timezone, "");
 
-  pos = strstr (line, "zoneinfo/");
-  if (!pos) goto cannot_read_localtime;
-
-  pos += strlen ("zoneinfo/");
-
-  localtime = g_strdup (pos);
-
- cannot_read_localtime:
   my = NULL;
 
-  while(!feof(tz))
+  while(1)
   {
     int i=0;
     int cnt=0;
-
+    
     memset(line, 0, sizeof (line));
     fgets(line, 1024, tz);
+    if(feof(tz)) break;
     if((line[0]=='#') || (line[0]==0))
       continue;
 
     while((i<1024) && (cnt < 3))
       {
-	while((i< 1024) && (line[i]!=0) && (line[i]!='\t') &&
-	      (line[i]!='\n') && !(cnt==2 && line[i]==' '))
+	while((i< 1024) && (line[i]!='\t') && line[i]!='\n' && !(cnt==2 && line[i]==' '))
 	  i++;
 	if(i==1024) break;
 	line[i++]=0;
 	newelem[cnt] = &(line[i]);
 	cnt++;
       }
-
-    if(i<1024)
+    
+    if((i<1024) && (strlen(newelem[1])>0))
       {
-	gint lat, lon, len;
+	gint lat, lon;
 	location *loc = malloc(sizeof(location));
 
 	sscanf(newelem[0], "%d%d", &lat, &lon);
@@ -74,21 +86,19 @@ void enum_timezones(GtkWidget *clist )
 	  }
 	strcpy((loc->name), newelem[1]);
 
-	len = strlen (loc->name);
-	if (len && (loc->name [len-1] == '\n'))
-		loc->name [len-1] = 0;
-
 	my = g_slist_insert_sorted(my, loc, cmp);
       }
+
   }
 
   inspos = 0;
   while(my)
     {
-      char *elems[2] = { ((location *)my->data)->name, NULL };
+      char *elems[2] = { NULL,NULL };
 
-      if (localtime && !strcmp (elems [0], localtime))
-	      localtime_data = (location *) my->data;
+      elems[0] = ((location *)my->data)->name;
+      if ((strlen(my_asclock->timezone)>0) && !strcmp (elems [0], my_asclock->timezone))
+	localtime_data = (location *) my->data;
 
       gtk_clist_append(GTK_CLIST(clist), elems );
       gtk_clist_set_row_data( GTK_CLIST(clist), inspos++, ((location *)my->data));
@@ -98,12 +108,13 @@ void enum_timezones(GtkWidget *clist )
   fclose(tz);
 
   gtk_clist_sort(GTK_CLIST(clist));
-
+  
   row = gtk_clist_find_row_from_data(GTK_CLIST(clist), localtime_data);
-  if (row >= 0) {
-	  gtk_clist_select_row(GTK_CLIST(clist), row, 0);
-	  gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5, 0.0);
-  }
+  if (row >= 0) 
+    {
+      gtk_clist_moveto(GTK_CLIST(clist), row, 0, 0.5, 0.0);
+      gtk_clist_select_row(GTK_CLIST(clist), row, 0);
+    }
 }
 
 
