@@ -18,6 +18,11 @@ typedef struct apm_info {
 #include <fcntl.h>
 #include <machine/apm_bios.h>
 #define APMDEV "/dev/apm"
+#elif defined(__NetBSD__) || defined(__OpenBSD__)
+#include <sys/ioctl.h>
+#include <machine/apmvar.h>
+#include <fcntl.h>
+#define APMDEV "/dev/apm"
 #endif
 
 /* Prototypes */ 
