@@ -49,6 +49,7 @@ gulong GWMHA_WIN_WORKSPACE_NAMES = 0;
 gulong GWMHA_WIN_CLIENT_LIST = 0;
 gulong GWMHA_WIN_AREA = 0;
 gulong GWMHA_WIN_AREA_COUNT = 0;
+gulong GWMHA_WIN_UNIFIED_AREA = 0;
 static gulong XA_WM_STATE = 0;
 static gulong XA_WM_PROTOCOLS = 0;
 static gulong XA_WM_DELETE_WINDOW = 0;
@@ -69,7 +70,8 @@ static const struct {
   { &GWMHA_WIN_CLIENT_LIST,		"_WIN_CLIENT_LIST", },
   { &GWMHA_WIN_AREA,			"_WIN_AREA", },
   { &GWMHA_WIN_AREA_COUNT,		"_WIN_AREA_COUNT", },
-#define N_GWMHA_IGNORE_ATOMS (9)
+  { &GWMHA_WIN_UNIFIED_AREA,		"_WIN_UNIFIED_AREA", },
+#define N_GWMHA_IGNORE_ATOMS (10)
   { &GWMHA_WIN_LAYER,			"_WIN_LAYER", },
   { &GWMHA_WIN_APP_STATE,		"_WIN_APP_STATE", },
   { &GWMHA_WIN_STATE,			"_WIN_STATE", },
@@ -107,7 +109,7 @@ static void		gwmh_task_queue_full	  (GwmhTask          *task,
 						   GwmhTaskInfoMask   imask,
 						   GwmhTaskInfoMask   notify_mask);
 static void		gwmh_desk_update	  (GwmhDeskInfoMask   imask);
-static void		gwmh_task_update	  (GwmhTask          *task,
+static gboolean		gwmh_task_update	  (GwmhTask          *task,
 						   GwmhTaskInfoMask   imask,
 						   gboolean           skip_notify);
 static void		gwmh_desk_notify	  (GwmhDeskInfoMask   imask);
@@ -150,7 +152,10 @@ static GwmhDesk         gwmh_desk = {
   0	/* current_varea */,
   NULL	/* client_list */,
   FALSE /* detected_gnome_wm */,
+  FALSE /* unified_area */,
 };
+static gboolean		gwmh_hack_think_unified_area = FALSE;
+static gboolean		gwmh_hack_violate_client_msg = TRUE;
 
 
 /* --- functions --- */
@@ -242,6 +247,7 @@ gwmh_init (void)
   gwmh_desk.current_harea = 0;
   gwmh_desk.current_varea = 0;
   gwmh_desk.detected_gnome_wm = FALSE;
+  gwmh_desk.unified_area = FALSE;
 
   /* setup preinitialized atoms */
   for (i = 0; i < sizeof (gwmh_atoms) / sizeof (gwmh_atoms[0]); i++)
@@ -753,6 +759,7 @@ gwmh_property_atom2info (Atom     atom,
     { &GWMHA_WIN_WORKSPACE,		GWMH_DESK_INFO_CURRENT_DESKTOP, },
     { &GWMHA_WIN_WORKSPACE_NAMES,	GWMH_DESK_INFO_DESKTOP_NAMES, },
     { &GWMHA_WIN_WORKSPACE_COUNT,	GWMH_DESK_INFO_N_DESKTOPS, },
+    { &GWMHA_WIN_UNIFIED_AREA,		GWMH_DESK_INFO_N_AREAS, },
   }, task_atom_masks[] = {
     /* GwmhTaskInfoMask */
     { &GWMHA_WIN_APP_STATE,		GWMH_TASK_INFO_APP_STATE, },
@@ -840,7 +847,14 @@ gwmh_desk_update (GwmhDeskInfoMask imask)
       gint size = 0;
       guint32 *size_data;
       guint n_hareas, n_vareas;
-      
+
+      /* FIXME: this should be a property check for UNIFIED_AREA */
+      if (gwmh_hack_think_unified_area != gwmh_desk.unified_area)
+	{
+	  ichanges |= GWMH_DESK_INFO_CURRENT_AREA | GWMH_DESK_INFO_N_AREAS;
+	  gwmh_desk.unified_area = gwmh_hack_think_unified_area;
+	}
+
       size_data = get_typed_property_data (xdisplay, xwindow,
 					   GWMHA_WIN_AREA_COUNT,
 					   XA_CARDINAL,
@@ -935,7 +949,7 @@ gwmh_desk_update (GwmhDeskInfoMask imask)
     {
       gint size = 0;
       guint32 *indx_data;
-      guint harea, varea;
+      guint i, harea, varea;
       
       indx_data = get_typed_property_data (xdisplay, xwindow,
 					   GWMHA_WIN_AREA,
@@ -958,6 +972,12 @@ gwmh_desk_update (GwmhDeskInfoMask imask)
 	  gwmh_varea_cache[gwmh_desk.current_desktop] = gwmh_desk.current_varea;
           ichanges |= GWMH_DESK_INFO_CURRENT_AREA;
 	}
+      if (gwmh_desk.unified_area && (ichanges & GWMH_DESK_INFO_CURRENT_AREA))
+	for (i = 0; i < gwmh_desk.n_desktops; i++)
+	  {
+	    gwmh_harea_cache[i] = gwmh_desk.current_harea;
+	    gwmh_varea_cache[i] = gwmh_desk.current_varea;
+	  }
     }
   
   if (imask & GWMH_DESK_INFO_CLIENT_LIST)
@@ -1010,7 +1030,7 @@ gwmh_desk_update (GwmhDeskInfoMask imask)
     gwmh_desk_notify (ichanges);
 }
 
-static void
+static gboolean
 gwmh_task_update (GwmhTask        *task,
 		  GwmhTaskInfoMask imask,
 		  gboolean         skip_notify)
@@ -1064,8 +1084,11 @@ gwmh_task_update (GwmhTask        *task,
       get_task_root_and_frame (task);
       if (!task->xframe || !task->sroot)
 	{
-	  task_delete (task);
-	  return;
+	  /* eek, that's ugly, we need to get rid of this task as
+	   * soon as possible, but *not* right here.
+	   */
+	  gwmh_desk_queue_update (GWMH_DESK_INFO_CLIENT_LIST);
+	  return FALSE;
 	}
       if (task->xframe != xframe ||
 	  (task->sroot ? GSTC_PARENT_XWINDOW (task->sroot) : 0) != !xroot)
@@ -1318,6 +1341,8 @@ gwmh_task_update (GwmhTask        *task,
   
   if (!skip_notify && ichanges)
     gwmh_task_notify (task, GWMH_NOTIFY_INFO_CHANGED, ichanges);
+
+  return TRUE;
 }
 
 static gboolean
@@ -1582,12 +1607,19 @@ task_new (GdkWindow *window)
   /* gwmh_task_update () will do this for us:
    * get_task_root_and_frame (task);
    */
-  gwmh_task_update (task, GWMH_TASK_INFO_ALL, TRUE);
+  if (gwmh_task_update (task, GWMH_TASK_INFO_ALL, TRUE))
+    {
+      gwmh_task_notify (task, GWMH_NOTIFY_NEW, 0);
+      gwmh_task_update (task, 0, FALSE);
 
-  gwmh_task_notify (task, GWMH_NOTIFY_NEW, 0);
-  gwmh_task_update (task, 0, FALSE);
+      return task;
+    }
+  else
+    {
+      task_delete (task);
 
-  return task;
+      return NULL;
+    }
 }
 
 static void
@@ -1644,6 +1676,18 @@ task_delete (GwmhTask *task)
   gwmh_desk.client_list = g_list_remove (gwmh_desk.client_list, task);
   g_free (task->name);
   task->name = "DELETED";
+
+  if (g_list_find (gwmh_desk.client_list, task))
+    {
+      g_warning ("deleted task still in client_list\n"); /* FIXME */
+      g_assert_not_reached ();
+    }
+  if (g_slist_find (gwmh_task_queue, task))
+    {
+      g_warning ("deleted task still in queue\n"); /* FIXME */
+      g_assert_not_reached ();
+    }
+    
   g_free (task);
 }
 
@@ -1685,13 +1729,18 @@ client_list_sync (Window *xwindows,
 
       if (window)
 	{
-	  client_list = g_list_prepend (client_list,
-					task_new (window));
-	  clients_changed = TRUE;
+	  GwmhTask *task = task_new (window);
+
+	  if (task)
+	    {
+	      client_list = g_list_prepend (client_list, task);
+	      clients_changed = TRUE;
+	    }
 	  gdk_window_unref (window);
 	}
     }
 
+  g_assert (g_list_length (gwmh_desk.client_list) == g_list_length (client_list)); /* FIXME */
   if (clients_changed)
     {
       g_list_free (gwmh_desk.client_list);
@@ -1808,14 +1857,13 @@ gwmh_task_deiconify (GwmhTask *task)
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_ICONIFIED, FALSE);
-
-  if (GWMH_TASK_ICONIFIED (task))
+  if (gwmh_task_update (task, GWMH_TASK_INFO_ICONIFIED, FALSE) &&
+      GWMH_TASK_ICONIFIED (task))
     {
       gdk_error_trap_push ();
-
+      
       XMapWindow (GDK_DISPLAY (), task->xwin);
-
+      
       gwmh_sync ();
       gdk_error_trap_pop ();
     }
@@ -1826,7 +1874,8 @@ gwmh_task_focus (GwmhTask *task)
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_FOCUSED, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_FOCUSED, FALSE))
+    return;
 
   if (wm_protocol_check_support (task->xwin, XA_WM_TAKE_FOCUS))
     send_client_message_32 (task->xwin, task->xwin,
@@ -1850,11 +1899,12 @@ gwmh_task_show (GwmhTask *task)
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task,
-		    (GWMH_TASK_INFO_ICONIFIED |
-		     GWMH_TASK_INFO_FOCUSED |
-		     GWMH_TASK_INFO_GSTATE),
-		    FALSE);
+  if (!gwmh_task_update (task,
+			 (GWMH_TASK_INFO_ICONIFIED |
+			  GWMH_TASK_INFO_FOCUSED |
+			  GWMH_TASK_INFO_GSTATE),
+			 FALSE))
+    return;
 
   if (!GWMH_TASK_SKIP_FOCUS (task) &&
       wm_protocol_check_support (task->xwin, XA_WM_TAKE_FOCUS))
@@ -1902,7 +1952,8 @@ gwmh_task_set_gstate_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE))
+    return;
 
   if ((GWMH_TASK_GSTATE (task) & flags) != flags)
     send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
@@ -1917,7 +1968,8 @@ gwmh_task_unset_gstate_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GSTATE, FALSE))
+    return;
 
   if (GWMH_TASK_GSTATE (task) & flags)
     send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
@@ -1932,7 +1984,8 @@ gwmh_task_set_ghint_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE))
+    return;
 
   if ((GWMH_TASK_GHINTS (task) & flags) != flags)
     send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
@@ -1947,7 +2000,8 @@ gwmh_task_unset_ghint_flags (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_GHINTS, FALSE))
+    return;
 
   if (GWMH_TASK_GHINTS (task) & flags)
     send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
@@ -1962,7 +2016,8 @@ gwmh_task_set_app_state (GwmhTask        *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_APP_STATE, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_APP_STATE, FALSE))
+    return;
 
   if (GWMH_TASK_APP_STATE (task) != app_state)
     send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
@@ -2032,7 +2087,8 @@ gwmh_task_set_layer (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_LAYER, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_LAYER, FALSE))
+    return;
 
   if (task->layer != layer)
     send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
@@ -2049,7 +2105,8 @@ gwmh_task_set_area (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP | GWMH_TASK_INFO_AREA, FALSE);
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP | GWMH_TASK_INFO_AREA, FALSE))
+    return;
   
   if (desktop >= gwmh_desk.n_desktops ||
       harea >= gwmh_desk.n_hareas ||
@@ -2062,7 +2119,10 @@ gwmh_task_set_area (GwmhTask *task,
   gwmh_sync ();
   gwmh_freeze_syncs ();
 
-  if (1) /* ugly hack for buggy window managers */
+  /* ugly hack for buggy window managers
+   * that violate the spec and expect us to modify properties directly
+   */
+  if (gwmh_hack_violate_client_msg)
     {
       long data[2];
       
@@ -2080,17 +2140,19 @@ gwmh_task_set_area (GwmhTask *task,
 
       gdk_error_trap_pop ();
     }
-
-  if (desktop != task->desktop)
-    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
-			    GWMHA_WIN_WORKSPACE,
-			    SubstructureNotifyMask,
-			    2, desktop, CurrentTime);
-  send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
-			  GWMHA_WIN_AREA,
-			  SubstructureNotifyMask,
-			  3, harea, varea, CurrentTime);
-
+  else
+    {
+      if (desktop != task->desktop)
+	send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+				GWMHA_WIN_WORKSPACE,
+				SubstructureNotifyMask,
+				2, desktop, CurrentTime);
+      send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+			      GWMHA_WIN_AREA,
+			      SubstructureNotifyMask,
+			      3, harea, varea, CurrentTime);
+    }
+  
   gwmh_thaw_syncs ();
 }
 
@@ -2100,12 +2162,14 @@ gwmh_task_set_desktop (GwmhTask *task,
 {
   g_return_if_fail (task != NULL);
 
-  gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP, FALSE);
-  
-  if (desktop >= gwmh_desk.n_desktops || task->desktop == desktop)
+  if (!gwmh_task_update (task, GWMH_TASK_INFO_DESKTOP, FALSE) ||
+      desktop >= gwmh_desk.n_desktops || task->desktop == desktop)
     return;
   
-  if (1) /* ugly hack for buggy window managers */
+  /* ugly hack for buggy window managers
+   * that violate the spec and expect us to modify properties directly
+   */
+  if (gwmh_hack_violate_client_msg)
     {
       long data[2];
       
@@ -2115,14 +2179,14 @@ gwmh_task_set_desktop (GwmhTask *task,
       if (desktop != task->desktop)
 	XChangeProperty (GDK_DISPLAY (), task->xwin, GWMHA_WIN_WORKSPACE,
 			 XA_CARDINAL, 32, PropModeReplace, (unsigned char*) data, 1);
-
+      
       gdk_error_trap_pop ();
     }
-
-  send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
-			  GWMHA_WIN_WORKSPACE,
-			  SubstructureNotifyMask,
-			  2, desktop, CurrentTime);
+  else
+    send_client_message_32 (GDK_ROOT_WINDOW (), task->xwin,
+			    GWMHA_WIN_WORKSPACE,
+			    SubstructureNotifyMask,
+			    2, desktop, CurrentTime);
 }
 
 GwmhDesk*
@@ -2165,6 +2229,16 @@ gwmh_desk_set_current_desktop (guint desktop)
 			  2, desktop, CurrentTime);
 }
 
+void
+gwmh_desk_set_hack_values (gboolean unified_area,
+			   gboolean violate_client_msg)
+{
+  gwmh_hack_think_unified_area = unified_area != FALSE;
+  gwmh_hack_violate_client_msg = violate_client_msg != FALSE;
+
+  gwmh_desk_update (GWMH_DESK_INFO_N_AREAS);
+}
+
 void
 gwmh_desk_set_current_area (guint desktop,
 			    guint harea,
@@ -2373,8 +2447,13 @@ hack_a_client_list (Display *display,
   
   gdk_error_trap_push ();
 
+  XGrabServer (display);
+
   if (!XQueryTree (display, xroot, &xwindow, &dummy, &children, &n_children) || !children)
-    return NULL;
+    {
+      XUngrabServer (display);
+      return NULL;
+    }
   
   for (i = 0; i < n_children; i++)
     {
@@ -2388,6 +2467,8 @@ hack_a_client_list (Display *display,
 	  clients[n_clients - 1] = xwindow;
 	}
     }
+
+  XUngrabServer (display);
   
   XFree (children);
   
