@@ -14,9 +14,9 @@
 #include <gnome.h>
 #include <applet-widget.h>
 
-#define DRIVEMOUNT_APPLET_VERSION_MAJ 0
-#define DRIVEMOUNT_APPLET_VERSION_MIN 99
-#define DRIVEMOUNT_APPLET_VERSION_REV 0
+#define DRIVEMOUNT_APPLET_VERSION_MAJ 1
+#define DRIVEMOUNT_APPLET_VERSION_MIN 0
+#define DRIVEMOUNT_APPLET_VERSION_REV 1
 
 typedef struct _DriveData DriveData;
 struct _DriveData
@@ -26,22 +26,22 @@ struct _DriveData
 	GtkWidget *button_pixmap;
 	GdkPixmap *pixmap_for_in;
 	GdkPixmap *pixmap_for_out;
-	int device_pixmap;
-	int timeout_id;
-	int interval;
-	int mounted;
-	int autofs_friendly;
-	char *mount_base;
-	char *mount_point;
+	gint device_pixmap;
+	gint timeout_id;
+	gint interval;
+	gint mounted;
+	gint autofs_friendly;
+	gchar *mount_base;
+	gchar *mount_point;
 	PanelOrientType orient;
 	GtkTooltips *tooltip;
 	/* the rest is for the properties window */
 	GtkWidget *propwindow;
 	GtkWidget *prop_spin;
 	GtkWidget *mount_point_entry;
-	int prop_interval;
-	int prop_device_pixmap;
-	int prop_autofs_friendly;
+	gint prop_interval;
+	gint prop_device_pixmap;
+	gint prop_autofs_friendly;
 };
 
 
@@ -49,7 +49,7 @@ void create_pixmaps(DriveData *dd);
 void redraw_pixmap(DriveData *dd);
 void start_callback_update(DriveData *dd);
 
-void property_load(char *path, DriveData *dd);
-void property_save(char *path, DriveData *dd);
+void property_load(gchar *path, DriveData *dd);
+void property_save(gchar *path, DriveData *dd);
 void property_show(AppletWidget *applet, gpointer data);
 
