@@ -55,7 +55,7 @@ static  gkb_properties defaults = {
 
 	gnome_config_push_prefix(APPLET_WIDGET(gkb->applet)->privcfgpath);
 	g_free(gkb->properties.command);
-	g_snprintf(buf,256,"gkb/name=%s",defaults.command);
+	g_snprintf(buf,256,"gkb/command=%s",defaults.command);
 	gkb->properties.command = gnome_config_get_string(buf);
 	g_free(gkb->properties.image[0]);
 	g_snprintf(buf,256,"gkb/image0=%s",gnome_unconditional_pixmap_file("gkb/us.xpm"));
@@ -167,7 +167,7 @@ properties_dialog(AppletWidget *applet,
 
 static	char *basemaps[]= {
 	"be", "bg", "ch", "cz", "de", "dk", "dvorak",
-	"es", "fi", "fr", "fr-2", "gr", "hu", "il", "is", 
+	"ee", "es", "fi", "fr", "fr-2", "gr", "hu", "il", "is", 
 	"it", "la", "nl", "no", "pl", "pt", "pt-dead", "qc", 
 	"ru", "ru_koi8", "se", "sf", "sg", "si", "sk", 
 	"th", "tr_f", "tr_q", "uk", "us", "yu", 0 
