@@ -414,11 +414,12 @@ initCommandEntry(void)
 	style->base[GTK_STATE_NORMAL].red = (gushort) prop.cmdLineColorBgR;
 	style->base[GTK_STATE_NORMAL].green = (gushort) prop.cmdLineColorBgG;
 	style->base[GTK_STATE_NORMAL].blue = (gushort) prop.cmdLineColorBgB;
+	style->bg[GTK_STATE_NORMAL] = style->base[GTK_STATE_NORMAL];
 
         /* create the widget we are going to put on the applet */
-	gtk_widget_push_style (style);
         entryCommand = gtk_entry_new_with_max_length((guint16) MAX_COMMAND_LENGTH); 
-	gtk_widget_pop_style ();
+	gtk_widget_set_style (GTK_WIDGET (entryCommand), style);
+
 	gtk_widget_set_usize(GTK_WIDGET(entryCommand), -1, prop.cmdLineY);
 
 
