@@ -89,9 +89,13 @@ openMixer( gchar *device_name )
 
 	mixerfd = open(device_name, O_RDWR, 0);
 	if (mixerfd < 0) {
-		/* probably should die more gracefully */
-		g_message(_("Couldn't open mixer device %s\n"),device_name);
-		exit(1);
+		GtkWidget *d;
+		char *s = g_strdup_printf (_("Couldn't open mixer device %s\n"),
+					   device_name);
+		d = gnome_error_dialog (s);
+		gnome_dialog_run (GNOME_DIALOG (d));
+		applet_widget_remove (applet);
+		gtk_exit (1);
 	}
 
         /*
@@ -560,7 +564,6 @@ main(int argc, char **argv)
 	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
 	textdomain(PACKAGE);
 
-	openMixer("/dev/mixer");
 	applet_widget_init("mixer_applet", VERSION, argc, argv,
 				    NULL, 0, NULL);
 
@@ -568,6 +571,8 @@ main(int argc, char **argv)
 	if (!applet)
 		g_error(("Can't create applet!\n"));
 
+	openMixer("/dev/mixer");
+
 	mixerw = create_mixer_widget();
 	gtk_widget_show(mixerw);
 	applet_widget_add(APPLET_WIDGET(applet), mixerw);
