@@ -37,7 +37,7 @@
 #include <ctype.h>
 #include <sys/stat.h>
 
-#ifdef __OpenBSD__
+#if defined(__OpenBSD__) || defined(__NetBSD__)
 #include <net/if_ppp.h>
 #endif
 
@@ -136,7 +136,7 @@ static void about_cb (AppletWidget *widget, gpointer data)
 			"(C) 1999",
 			authors,
 			_("Released under the GNU general public license.\n"
-			"A modem status indicator and dialer."
+			"A modem status indicator and dialer.\n"
 			"Lights in order from the top or left are RX and TX"),
 			NULL);
 	gtk_widget_show (about);
@@ -285,13 +285,13 @@ static int get_modem_stats(int *in, int *out)
 	struct 	ppp_stats stats;
 
 	memset(&ifreq, 0, sizeof(ifreq));
-#if defined(__FreeBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
 	strncpy(ifreq.ifr_name, device_name, IFNAMSIZ);
 #else
 	strncpy(ifreq.ifr_ifrn.ifrn_name, device_name, IFNAMSIZ);
 #endif /* FreeBSD or OpenBSD */
 	ifreq.ifr_ifru.ifru_data = (caddr_t)&stats;
-#if defined(__FreeBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
 		if ((ioctl(ip_socket,SIOCGPPPSTATS,(caddr_t)&ifreq) < 0))
 #else
 #ifdef SIOCDEVPRIVATE
