@@ -43,6 +43,10 @@ fixup_task_label (TasklistTask *task)
 
 	label_len = gdk_string_width (area->style->font,
 				      task->gwmh_task->name);
+	
+	if (GWMH_TASK_ICONIFIED (task->gwmh_task))
+		label_len += gdk_string_width (area->style->font,
+					       "[]");
 
 	if (label_len > task->width - ROW_HEIGHT) {
 		len = strlen (task->gwmh_task->name);
@@ -56,6 +60,9 @@ fixup_task_label (TasklistTask *task)
 			
 			label_len = gdk_string_width (area->style->font, str);
 			
+			if (GWMH_TASK_ICONIFIED (task->gwmh_task))
+				label_len += gdk_string_width (area->style->font,
+							       "[]");
 			if (label_len <= task->width - (Config.show_mini_icons ? 24:6))
 				break;
 		}
@@ -63,6 +70,10 @@ fixup_task_label (TasklistTask *task)
 	else
 		str = g_strdup (task->gwmh_task->name);
 
+	if (GWMH_TASK_ICONIFIED (task->gwmh_task)) {
+		str = g_strdup_printf ("[%s]", str);
+	}
+
 	return str;
 }
 
@@ -251,7 +262,6 @@ layout_tasklist (void)
 	temp_tasks = get_visible_tasks ();
 	num = g_list_length (temp_tasks);
 	
-
 	switch (applet_widget_get_panel_orient (APPLET_WIDGET (applet))) {
 	case ORIENT_UP:
 	case ORIENT_DOWN:
@@ -428,6 +438,10 @@ gboolean
 desk_notifier (gpointer func_data, GwmhDesk *desk,
 	       GwmhDeskInfoMask change_mask)
 {
+	if (Config.all_desks_minimized && 
+	    Config.all_desks_normal)
+		return TRUE;
+
 	layout_tasklist ();
 
 	return TRUE;
@@ -440,7 +454,7 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 	       GwmhTaskInfoMask imask)
 {
 	TasklistTask *task;
-
+	
 	switch (ntype)
 	{
 	case GWMH_NOTIFY_INFO_CHANGED:
@@ -452,9 +466,14 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 			draw_task (find_gwmh_task (gwmh_task));
 		if (imask & GWMH_TASK_INFO_MISC)
 			draw_task (find_gwmh_task (gwmh_task));
-		if (imask & GWMH_TASK_INFO_DESKTOP)
+		if (imask & GWMH_TASK_INFO_DESKTOP) {
+			if (Config.all_desks_minimized && 
+			    Config.all_desks_normal)
+				break;
+
 			/* Redraw entire tasklist */
 			layout_tasklist ();
+		}
 		break;
 	case GWMH_NOTIFY_NEW:
 		task = g_malloc0 (sizeof (TasklistTask));
@@ -708,3 +727,5 @@ main (gint argc, gchar *argv[])
 
 
 
+
+
