@@ -99,6 +99,7 @@ struct terminal_config {
 	int transparent;
 	int shaded;
 	int background_pixmap;
+	int terminal_id;			/* terminal id for this terminal */
 	char *pixmap_file;
         char *window_title;                     /* the window title */
 	char *wordclass;			/* select-by-word character class */
@@ -116,6 +117,9 @@ GtkWidget *initial_term = NULL;
 /* A list of all the open terminals */
 GList *terminals = 0;
 
+/* current new terminal window id */
+static int terminal_id = 0;
+
 typedef struct {
 	GtkWidget *prop_win;
 	GtkWidget *blink_checkbox;
@@ -181,7 +185,7 @@ void toggle_secure_keyboard_cmd (GtkWidget *w, ZvtTerm *term);
 static int popup_menu_cmd (ZvtTerm *term, GdkEventButton *event,
 			   GtkWidget *menu, GnomeUIInfo *uiinfo);
 
-GtkWidget *new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry);
+GtkWidget *new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry, int termid);
 GtkWidget *new_terminal     (GtkWidget *widget, ZvtTerm *term);
 
 static void parse_an_arg (poptContext state,
@@ -197,14 +201,20 @@ about_terminal_cmd (void)
         GtkWidget *about;
 
         const gchar *authors[] = {
-		"Zvt terminal widget: "
-		"    Michael Zucchi (zucchi@zedzone.mmc.com.au)",
-		"GNOME terminal: "
-		"    Miguel de Icaza (miguel@kernel.org)",
-		"    Erik Troan (ewt@redhat.com)",
+	     N_("Zvt terminal widget: "
+		"    Michael Zucchi (zucchi@zedzone.mmc.com.au)"),
+	     N_("GNOME terminal: "
+		"    Miguel de Icaza (miguel@kernel.org)"),
+	     N_("    Erik Troan (ewt@redhat.com)"),
 		NULL
 	};
 
+#ifdef ENABLE_NLS
+	authors[0]=_(authors[0]);
+	authors[1]=_(authors[1]);
+	authors[2]=_(authors[2]);
+#endif
+
         about = gnome_about_new (_("GNOME Terminal"), VERSION,
 				 "(C) 1998, 1999 the Free Software Foundation",
 				 authors,
@@ -495,6 +505,7 @@ load_config (char *class)
 	cfg->window_title = NULL;
 
 	cfg->termname = NULL;
+	cfg->terminal_id = 0;
 
 	cfg->update_records = ZVT_TERM_DO_UTMP_LOG|ZVT_TERM_DO_WTMP_LOG;
 
@@ -1942,7 +1953,7 @@ show_pty_error_dialog (int errcode)
 }
 
 GtkWidget *
-new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
+new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry, int termid)
 {
 	GtkWidget *app, *hbox, *scrollbar;
 	ZvtTerm   *term;
@@ -1961,6 +1972,8 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 
 	cfg = terminal_config_dup (cfg_in);
 
+	cfg->terminal_id = termid;
+
 	/* Setup the environment for the gnome-terminals:
 	 *
 	 * TERM is set to xterm (which is what zvt emulates)
@@ -2014,7 +2027,7 @@ new_terminal_cmd (char **cmd, struct terminal_config *cfg_in, gchar *geometry)
 	if (cfg->window_title) {
 	  gtk_window_set_title(GTK_WINDOW(app), cfg->window_title);
  	}
-	sprintf(winclass, "GnomeTerminal:%p", app);
+	sprintf(winclass, "GnomeTerminal.%d", termid);
 	gtk_window_set_wmclass (GTK_WINDOW (app), "GnomeTerminal", winclass);
 	gtk_window_set_policy(GTK_WINDOW (app), TRUE, TRUE, TRUE);
 
@@ -2189,7 +2202,7 @@ new_terminal (GtkWidget *widget, ZvtTerm *term)
 
 	cfg = gtk_object_get_data (GTK_OBJECT (term), "config");
 
-	return new_terminal_cmd (NULL, cfg, NULL);
+	return new_terminal_cmd (NULL, cfg, NULL, terminal_id++);
 }
 
 static gboolean
@@ -2215,7 +2228,9 @@ load_session ()
 		char *class, *class_path;
 		int argc;
 		char *prefix = g_strdup_printf ("%s%d/", file, i);
-	  
+		int termid;
+		char termconf[16];
+
 		gnome_config_push_prefix (prefix);
 
 		/* NAUGHTY: The ICCCM requires that the WM stores
@@ -2246,10 +2261,14 @@ load_session ()
 		if (gnome_config_get_bool ("do_wtmp=true"))
 			cfg->update_records |= ZVT_TERM_DO_WTMP_LOG;
 
+		termid = gnome_config_get_int("terminal_id=-1");
+		if (termid!=-1)
+			terminal_id = termid;
+
 		g_free(class);
 		gnome_config_pop_prefix();
 
-		new_terminal_cmd (argv, cfg, geom);
+		new_terminal_cmd (argv, cfg, geom, terminal_id++);
 
 		g_free(cfg);
 		g_free (geom);
@@ -2322,6 +2341,7 @@ save_session (GnomeClient *client, gint phase, GnomeSaveStyle save_style,
 		g_string_free (geom, TRUE);
 		
 		gnome_config_set_string("class", cfg->class);
+		gnome_config_set_int("terminal_id", cfg->terminal_id);
 		
 		if (top == initial_term){
 			int n;
@@ -2660,7 +2680,7 @@ main_terminal_program (int argc, char *argv [], char **environ)
 	terminal_config_free (cmdline_config);
 	
 	if (!load_session ())
-		new_terminal_cmd (initial_command, default_config, initial_global_geometry);
+		new_terminal_cmd (initial_command, default_config, initial_global_geometry, terminal_id++);
 
 	terminal_config_free (default_config);
 
