@@ -140,11 +140,11 @@ static void appendEntry(History h, gchar *ref, gint date, guint count)
     entry->timestamp = (time_t)date;
     g_hash_table_insert(h->table, entry->ref, entry);
 
-    snprintf(buf0, sizeof(buf0), "%s", ref);
+    g_snprintf(buf0, sizeof(buf0), "%s", ref);
     timet = (time_t)entry->timestamp;
     tstruct = localtime(& timet);
     strftime(buf1, sizeof(buf1), "%b %d, %Y %H:%M", tstruct);
-    snprintf(buf2, sizeof(buf2), "%d", entry->count);
+    g_snprintf(buf2, sizeof(buf2), "%d", entry->count);
 
     text[0] = buf0;
     text[1] = buf1;
@@ -195,11 +195,11 @@ void addToHistory(History h, gchar *ref)
     }
     entry->timestamp = time(NULL);
 
-    snprintf(buf0, sizeof(buf0), "%s", ref);
+    g_snprintf(buf0, sizeof(buf0), "%s", ref);
     timet = (time_t)entry->timestamp;
     tstruct = localtime(& timet);
     strftime(buf1, sizeof(buf1), "%b %d, %Y %H:%M", tstruct);
-    snprintf(buf2, sizeof(buf2), "%d", entry->count);
+    g_snprintf(buf2, sizeof(buf2), "%d", entry->count);
 
     text[0] = buf0;
     text[1] = buf1;
@@ -316,4 +316,3 @@ static void createHistoryWindow(History h, GtkWidget **window,
     gtk_signal_connect_after(GTK_OBJECT(*clist), "select_row",
 		       GTK_SIGNAL_FUNC(mouseDoubleClick), h);
 }
-
