@@ -465,26 +465,6 @@ queue_resize_foreach(GtkWidget *w, gpointer data)
 	}
 }
 
-/*the following is slightly ugly .... but it works, I need to send the
-  orient change in an idle handeler*/
-static int
-panel_applet_added_idle(gpointer data)
-{
-	AppletInfo *info = data;
-	PanelWidget *panel;
-	
-	g_return_val_if_fail(info,FALSE);
-	g_return_val_if_fail(info->widget,TRUE);
-	g_return_val_if_fail(info->widget->parent,TRUE);
-
-	panel = PANEL_WIDGET(info->widget->parent);
-
-	orientation_change(info,panel);
-	back_change(info,panel);
-
-	return FALSE;
-}
-
 static void
 panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 {
@@ -524,7 +504,8 @@ panel_applet_added(GtkWidget *widget, GtkWidget *applet, gpointer data)
 		corner_widget_queue_pop_down(CORNER_WIDGET(panelw));
 	}
 
-	gtk_idle_add(panel_applet_added_idle,info);
+	orientation_change(info,PANEL_WIDGET(BASEP_WIDGET(panelw)->panel));
+	back_change(info,PANEL_WIDGET(BASEP_WIDGET(panelw)->panel));
 
 	/*we will need to save this applet's config now*/
 	applets_to_sync = TRUE;
@@ -910,7 +891,7 @@ panel_widget_dnd_drop_internal (GtkWidget *widget,
 		int pos = panel_widget_get_cursorloc(panel);
 
 		files =
-		  gnome_uri_list_extract_filenames(selection_data->data);
+		  gnome_uri_list_extract_filenames((gchar *)selection_data->data);
 
 		for(ltmp = files; ltmp; ltmp = g_list_next(ltmp)) {
 		  const char *mimetype, *p;
@@ -933,7 +914,7 @@ panel_widget_dnd_drop_internal (GtkWidget *widget,
 					      (char *)ltmp->data);
 			  load_launcher_applet_from_info(ltmp->data,
 							 p,exec,2,
-							 "netscape.png",
+							 "gnome-html.png",
 							 panel,pos);
 			  g_free(p);
 		  }
@@ -973,9 +954,9 @@ panel_widget_dnd_drop_internal (GtkWidget *widget,
 		};
 		char *p;
 		
-         	exec[1] = selection_data->data;
+         	exec[1] = (gchar *)selection_data->data;
 		p = g_strdup_printf("Open URL: %s",selection_data->data);
-		load_launcher_applet_from_info(selection_data->data,p,exec,2,
+		load_launcher_applet_from_info((gchar *)selection_data->data,p,exec,2,
 					       "netscape.png",panel,pos);
 		g_free(p);
 		break;
